@@ -19,11 +19,9 @@ def relay(**kw):
     # Do just like in fedmsg.commands.hub and mangle fedmsg-config.py to work
     # with moksha's expected configuration.
     moksha_options = dict(
-        zmq_enabled=True,
         zmq_publish_endpoints=kw['endpoints']["relay_outbound"],
         zmq_subscribe_endpoints=kw['relay_inbound'],
         zmq_subscribe_method="bind",
-        zmq_strict=False,
     )
     kw.update(moksha_options)
 
